Documentation
¶
Index ¶
- Constants
- Variables
- type Clock_t
- type Clockid_t
- type Cpu_set_t
- type Itimerspec
- type Locale_t
- type Pid_t
- type Pthread_attr_t
- type Pthread_attr_t1
- type Pthread_barrier_t
- type Pthread_barrierattr_t
- type Pthread_cond_t
- type Pthread_condattr_t
- type Pthread_key_t
- type Pthread_mutex_t
- type Pthread_mutexattr_t
- type Pthread_once_t
- type Pthread_rwlock_t
- type Pthread_rwlockattr_t
- type Pthread_spinlock_t
- type Pthread_t
- type Ptrdiff_t
- type Sched_param
- type Size_t
- type Time_t
- type Timer_t
- type Timespec
- type Tm
- type Wchar_t
- type X__blkcnt64_t
- type X__blkcnt_t
- type X__blksize_t
- type X__builtin_va_list
- type X__caddr_t
- type X__clock_t
- type X__clockid_t
- type X__cpu_mask
- type X__daddr_t
- type X__dev_t
- type X__float128
- type X__fsblkcnt64_t
- type X__fsblkcnt_t
- type X__fsfilcnt64_t
- type X__fsfilcnt_t
- type X__fsid_t
- type X__fsword_t
- type X__gid_t
- type X__id_t
- type X__ino64_t
- type X__ino_t
- type X__int8_t
- type X__int16_t
- type X__int32_t
- type X__int64_t
- type X__int128_t
- type X__int_least8_t
- type X__int_least16_t
- type X__int_least32_t
- type X__int_least64_t
- type X__intmax_t
- type X__intptr_t
- type X__jmp_buf
- type X__key_t
- type X__locale_struct
- type X__locale_t
- type X__loff_t
- type X__mode_t
- type X__nlink_t
- type X__off64_t
- type X__off_t
- type X__pid_t
- type X__pthread_cleanup_frame
- type X__pthread_cond_s
- type X__pthread_internal_list
- type X__pthread_list_t
- type X__pthread_mutex_s
- type X__pthread_rwlock_arch_t
- type X__pthread_unwind_buf_t
- type X__quad_t
- type X__rlim64_t
- type X__rlim_t
- type X__sig_atomic_t
- type X__socklen_t
- type X__ssize_t
- type X__suseconds_t
- type X__syscall_slong_t
- type X__syscall_ulong_t
- type X__time_t
- type X__timer_t
- type X__u_char
- type X__u_int
- type X__u_long
- type X__u_quad_t
- type X__u_short
- type X__uid_t
- type X__uint8_t
- type X__uint16_t
- type X__uint32_t
- type X__uint64_t
- type X__uint128_t
- type X__uint_least8_t
- type X__uint_least16_t
- type X__uint_least32_t
- type X__uint_least64_t
- type X__uintmax_t
- type X__useconds_t
- type X_pthread_cleanup_buffer
Constants ¶
const ( BIG_ENDIAN = 4321 BYTE_ORDER = 1234 CLOCK_BOOTTIME = 7 CLOCK_BOOTTIME_ALARM = 9 CLOCK_MONOTONIC = 1 CLOCK_MONOTONIC_COARSE = 6 CLOCK_MONOTONIC_RAW = 4 CLOCK_PROCESS_CPUTIME_ID = 2 CLOCK_REALTIME = 0 CLOCK_REALTIME_ALARM = 8 CLOCK_REALTIME_COARSE = 5 CLOCK_TAI = 11 CLOCK_THREAD_CPUTIME_ID = 3 LITTLE_ENDIAN = 1234 PDP_ENDIAN = 3412 PTHREAD_BARRIER_SERIAL_THREAD = -1 PTHREAD_ONCE_INIT = 0 SCHED_FIFO = 1 SCHED_OTHER = 0 SCHED_RR = 2 TIMER_ABSTIME = 1 TIME_UTC = 1 X_ATFILE_SOURCE = 1 X_BITS_BYTESWAP_H = 1 X_BITS_CPU_SET_H = 1 X_BITS_PTHREADTYPES_ARCH_H = 1 X_BITS_PTHREADTYPES_COMMON_H = 1 X_BITS_SCHED_H = 1 X_BITS_SETJMP_H = 1 X_BITS_TIME_H = 1 X_BITS_TYPESIZES_H = 1 X_BITS_TYPES_H = 1 X_BITS_TYPES_LOCALE_T_H = 1 X_BITS_TYPES_STRUCT_SCHED_PARAM = 1 X_BITS_TYPES___LOCALE_T_H = 1 X_BITS_UINTN_IDENTITY_H = 1 X_BSD_SIZE_T_ = 0 X_BSD_SIZE_T_DEFINED_ = 0 X_DEFAULT_SOURCE = 1 X_ENDIAN_H = 1 X_FEATURES_H = 1 X_FILE_OFFSET_BITS = 64 X_GCC_SIZE_T = 0 X_LP64 = 1 X_POSIX_C_SOURCE = 200809 X_POSIX_SOURCE = 1 X_PTHREAD_H = 1 X_SCHED_H = 1 X_SIZET_ = 0 X_SIZE_T = 0 X_SIZE_T_ = 0 X_SIZE_T_DECLARED = 0 X_SIZE_T_DEFINED = 0 X_SIZE_T_DEFINED_ = 0 X_STDC_PREDEF_H = 1 X_STRUCT_TIMESPEC = 1 X_SYS_CDEFS_H = 1 X_SYS_SIZE_T_H = 0 X_THREAD_SHARED_TYPES_H = 1 X_TIME_H = 1 X_T_SIZE = 0 X_T_SIZE_ = 0 Linux = 1 Unix = 1 )
const ( PTHREAD_RWLOCK_PREFER_READER_NP = 0 PTHREAD_RWLOCK_PREFER_WRITER_NP = 1 PTHREAD_RWLOCK_PREFER_WRITER_NONRECURSIVE_NP = 2 PTHREAD_RWLOCK_DEFAULT_NP = 0 )
Read-write lock types.
const ( PTHREAD_INHERIT_SCHED = 0 PTHREAD_EXPLICIT_SCHED = 1 )
Scheduler inheritance.
const ( PTHREAD_SCOPE_SYSTEM = 0 PTHREAD_SCOPE_PROCESS = 1 )
Scope handling.
const ( PTHREAD_PROCESS_PRIVATE = 0 PTHREAD_PROCESS_SHARED = 1 )
Process shared or private flag.
const ( PTHREAD_CANCEL_ENABLE = 0 PTHREAD_CANCEL_DISABLE = 1 )
Cancellation
const ( PTHREAD_CANCEL_DEFERRED = 0 PTHREAD_CANCEL_ASYNCHRONOUS = 1 )
const ( PTHREAD_CREATE_JOINABLE = 0 PTHREAD_CREATE_DETACHED = 1 )
Detach state.
const ( PTHREAD_MUTEX_TIMED_NP = 0 PTHREAD_MUTEX_RECURSIVE_NP = 1 PTHREAD_MUTEX_ERRORCHECK_NP = 2 PTHREAD_MUTEX_ADAPTIVE_NP = 3 PTHREAD_MUTEX_NORMAL = 0 PTHREAD_MUTEX_RECURSIVE = 1 PTHREAD_MUTEX_ERRORCHECK = 2 PTHREAD_MUTEX_DEFAULT = 0 )
Mutex types.
const ( PTHREAD_MUTEX_STALLED = 0 PTHREAD_MUTEX_STALLED_NP = 0 PTHREAD_MUTEX_ROBUST = 1 PTHREAD_MUTEX_ROBUST_NP = 1 )
Robust mutex or not flags.
const ( PTHREAD_PRIO_NONE = 0 PTHREAD_PRIO_INHERIT = 1 PTHREAD_PRIO_PROTECT = 2 )
Mutex protocols.
Variables ¶
var CAPI = map[string]struct{}{}
Functions ¶
This section is empty.
Types ¶
type Clockid_t ¶
type Clockid_t = X__clockid_t /* clockid_t.h:7:21 */
Clock ID used in clock and timer functions.
type Cpu_set_t ¶
type Cpu_set_t = struct{ F__bits [16]X__cpu_mask } /* cpu-set.h:42:3 */
Data structure to describe CPU mask.
type Itimerspec ¶
type Itimerspec = struct {
Fit_interval struct {
Ftv_sec X__time_t
Ftv_nsec X__syscall_slong_t
}
Fit_value struct {
Ftv_sec X__time_t
Ftv_nsec X__syscall_slong_t
}
} /* struct_itimerspec.h:8:1 */
POSIX.1b structure for timer start values and intervals.
type Locale_t ¶
type Locale_t = X__locale_t /* locale_t.h:24:20 */
type Pthread_attr_t ¶
type Pthread_attr_t = Pthread_attr_t1 /* pthreadtypes.h:62:30 */
type Pthread_attr_t1 ¶
type Pthread_attr_t1 = struct {
F__size [56]int8
// contains filtered or unexported fields
} /* pthreadtypes.h:56:1 */
type Pthread_barrier_t ¶
type Pthread_barrier_t = struct {
F__size [32]int8
// contains filtered or unexported fields
} /* pthreadtypes.h:112:3 */
POSIX barriers data type. The structure of the type is
deliberately not exposed.
type Pthread_barrierattr_t ¶
type Pthread_barrierattr_t = struct {
F__size [4]int8
// contains filtered or unexported fields
} /* pthreadtypes.h:118:3 */
type Pthread_cond_t ¶
type Pthread_cond_t = struct{ F__data X__pthread_cond_s } /* pthreadtypes.h:80:3 */
type Pthread_condattr_t ¶
type Pthread_condattr_t = struct {
F__size [4]int8
// contains filtered or unexported fields
} /* pthreadtypes.h:45:3 */
Data structure for condition variable handling. The structure of
the attribute type is not exposed on purpose.
type Pthread_key_t ¶
type Pthread_key_t = uint32 /* pthreadtypes.h:49:22 */
Keys for thread-specific data
type Pthread_mutex_t ¶
type Pthread_mutex_t = struct{ F__data X__pthread_mutex_s } /* pthreadtypes.h:72:3 */
type Pthread_mutexattr_t ¶
type Pthread_mutexattr_t = struct {
F__size [4]int8
// contains filtered or unexported fields
} /* pthreadtypes.h:36:3 */
Data structures for mutex handling. The structure of the attribute
type is not exposed on purpose.
type Pthread_rwlock_t ¶
type Pthread_rwlock_t = struct{ F__data X__pthread_rwlock_arch_t } /* pthreadtypes.h:91:3 */
Data structure for reader-writer lock variable handling. The
structure of the attribute type is deliberately not exposed.
type Pthread_rwlockattr_t ¶
type Pthread_rwlockattr_t = struct {
F__size [8]int8
// contains filtered or unexported fields
} /* pthreadtypes.h:97:3 */
type Pthread_spinlock_t ¶
type Pthread_spinlock_t = int32 /* pthreadtypes.h:103:22 */
POSIX spinlock data type.
type Pthread_t ¶
type Pthread_t = uint64 /* pthreadtypes.h:27:27 */
Thread identifiers. The structure of the attribute type is not
exposed on purpose.
type Sched_param ¶
type Sched_param = struct{ Fsched_priority int32 } /* struct_sched_param.h:23:1 */
Data structure to describe a process' schedulability.
type Timespec ¶
type Timespec = struct {
Ftv_sec X__time_t
Ftv_nsec X__syscall_slong_t
} /* struct_timespec.h:9:1 */
POSIX.1b structure for a time value. This is like a `struct timeval' but
has nanoseconds instead of microseconds.
type Tm ¶
type Tm = struct {
Ftm_sec int32
Ftm_min int32
Ftm_hour int32
Ftm_mday int32
Ftm_mon int32
Ftm_year int32
Ftm_wday int32
Ftm_yday int32
Ftm_isdst int32
Ftm_gmtoff int64
Ftm_zone uintptr
// contains filtered or unexported fields
} /* struct_tm.h:7:1 */
ISO C `broken-down time' structure.
type X__blkcnt64_t ¶
type X__blkcnt64_t = int64 /* types.h:178:30 */
type X__blkcnt_t ¶
type X__blkcnt_t = int64 /* types.h:177:28 */
Type to count number of disk blocks.
type X__builtin_va_list ¶
type X__builtin_va_list = uintptr /* <builtin>:46:14 */
type X__caddr_t ¶
type X__caddr_t = uintptr /* types.h:201:14 */
type X__clock_t ¶
type X__clock_t = int64 /* types.h:154:27 */ // Type of CPU usage counts.
type X__clockid_t ¶
type X__clockid_t = int32 /* types.h:166:29 */
Clock ID used in clock and timer functions.
type X__cpu_mask ¶
type X__cpu_mask = uint64 /* cpu-set.h:32:25 */
Type for array elements in 'cpu_set_t'.
type X__daddr_t ¶
type X__daddr_t = int32 /* types.h:162:27 */ // The type of a disk address.
type X__float128 ¶
type X__float128 = float64 /* <builtin>:47:21 */
type X__fsblkcnt64_t ¶
type X__fsblkcnt64_t = uint64 /* types.h:182:32 */
type X__fsblkcnt_t ¶
type X__fsblkcnt_t = uint64 /* types.h:181:30 */
Type to count file system blocks.
type X__fsfilcnt64_t ¶
type X__fsfilcnt64_t = uint64 /* types.h:186:32 */
type X__fsfilcnt_t ¶
type X__fsfilcnt_t = uint64 /* types.h:185:30 */
Type to count file system nodes.
type X__fsid_t ¶
type X__fsid_t = struct{ F__val [2]int32 } /* types.h:153:26 */ // Type of file system IDs.
type X__fsword_t ¶
type X__fsword_t = int64 /* types.h:189:28 */
Type of miscellaneous file system fields.
type X__ino64_t ¶
type X__ino64_t = uint64 /* types.h:147:27 */ // Type of file serial numbers (LFS).
type X__int8_t ¶
type X__int8_t = int8 /* types.h:36:21 */
Fixed-size types, underlying types depend on word size and compiler.
type X__int16_t ¶
type X__int16_t = int16 /* types.h:38:26 */
type X__int32_t ¶
type X__int32_t = int32 /* types.h:40:20 */
type X__int64_t ¶
type X__int64_t = int64 /* types.h:43:25 */
type X__int128_t ¶
type X__int_least8_t ¶
type X__int_least8_t = X__int8_t /* types.h:51:18 */
Smallest types with at least a given width.
type X__int_least16_t ¶
type X__int_least16_t = X__int16_t /* types.h:53:19 */
type X__int_least32_t ¶
type X__int_least32_t = X__int32_t /* types.h:55:19 */
type X__int_least64_t ¶
type X__int_least64_t = X__int64_t /* types.h:57:19 */
type X__intptr_t ¶
type X__intptr_t = int64 /* types.h:204:25 */
Duplicates info from stdint.h but this is used in unistd.h.
type X__jmp_buf ¶
type X__jmp_buf = [8]int64 /* setjmp.h:31:18 */
type X__locale_struct ¶
type X__locale_t ¶
type X__locale_t = uintptr /* __locale_t.h:42:32 */
type X__loff_t ¶
type X__loff_t = X__off64_t /* types.h:200:19 */ // Type of file sizes and offsets (LFS).
These few don't really vary by system, they always correspond
to one of the other defined types.
type X__nlink_t ¶
type X__nlink_t = uint64 /* types.h:149:27 */ // Type of file link counts.
type X__off64_t ¶
type X__off64_t = int64 /* types.h:151:27 */ // Type of file sizes and offsets (LFS).
type X__pthread_cleanup_frame ¶
type X__pthread_cleanup_frame = struct {
F__cancel_routine uintptr
F__cancel_arg uintptr
F__do_it int32
F__cancel_type int32
} /* pthread.h:541:1 */
Structure to hold the cleanup handler information.
type X__pthread_cond_s ¶
type X__pthread_list_t ¶
type X__pthread_list_t = X__pthread_internal_list /* thread-shared-types.h:86:3 */
type X__pthread_mutex_s ¶
type X__pthread_rwlock_arch_t ¶
type X__pthread_rwlock_arch_t = struct {
F__readers uint32
F__writers uint32
F__wrphase_futex uint32
F__writers_futex uint32
F__pad3 uint32
F__pad4 uint32
F__cur_writer int32
F__rwelision int8
F__pad1 [7]uint8
F__pad2 uint64
F__flags uint32
// contains filtered or unexported fields
} /* pthreadtypes-arch.h:65:1 */
type X__pthread_unwind_buf_t ¶
type X__pthread_unwind_buf_t = struct {
F__cancel_jmp_buf [1]struct {
F__cancel_jmp_buf X__jmp_buf
F__mask_was_saved int32
// contains filtered or unexported fields
}
F__pad [4]uintptr
} /* pthread.h:532:3 */
type X__rlim64_t ¶
type X__rlim64_t = uint64 /* types.h:156:28 */ // Type for resource measurement (LFS).
type X__sig_atomic_t ¶
type X__sig_atomic_t = int32 /* types.h:212:13 */
C99: An integer type that can be accessed as an atomic entity,
even in the presence of asynchronous interrupts. It is not currently necessary for this to be machine-specific.
type X__socklen_t ¶
type X__socklen_t = uint32 /* types.h:207:23 */
Duplicate info from sys/socket.h.
type X__ssize_t ¶
type X__ssize_t = int64 /* types.h:191:27 */ // Type of a byte count, or error.
type X__suseconds_t ¶
type X__suseconds_t = int64 /* types.h:160:31 */ // Signed count of microseconds.
type X__syscall_slong_t ¶
type X__syscall_slong_t = int64 /* types.h:194:33 */
Signed long type used in system calls.
type X__syscall_ulong_t ¶
type X__syscall_ulong_t = uint64 /* types.h:196:33 */
Unsigned long type used in system calls.
type X__timer_t ¶
type X__timer_t = uintptr /* types.h:169:12 */
Timer ID returned by `timer_create'.
type X__u_quad_t ¶
type X__u_quad_t = uint64 /* types.h:63:27 */
type X__u_short ¶
type X__u_short = uint16 /* types.h:31:28 */
type X__uint8_t ¶
type X__uint8_t = uint8 /* types.h:37:23 */
type X__uint16_t ¶
type X__uint16_t = uint16 /* types.h:39:28 */
type X__uint32_t ¶
type X__uint32_t = uint32 /* types.h:41:22 */
type X__uint64_t ¶
type X__uint64_t = uint64 /* types.h:44:27 */
type X__uint128_t ¶
type X__uint_least8_t ¶
type X__uint_least8_t = X__uint8_t /* types.h:52:19 */
type X__uint_least16_t ¶
type X__uint_least16_t = X__uint16_t /* types.h:54:20 */
type X__uint_least32_t ¶
type X__uint_least32_t = X__uint32_t /* types.h:56:20 */
type X__uint_least64_t ¶
type X__uint_least64_t = X__uint64_t /* types.h:58:20 */
type X__uintmax_t ¶
type X__uintmax_t = uint64 /* types.h:72:27 */
type X__useconds_t ¶
type X__useconds_t = uint32 /* types.h:159:30 */ // Count of microseconds.